@@ -92,36 +92,36 @@ static char *models[] =
         "Pentium II \\(Deschutes\\)", "Pentium II (Deschutes)",
         "Pentium III \\(Katmai\\)", "Pentium III (Katmai)",
 	"Pentium III \\(Coppermine\\)", "Pentium III (Coppermine)",
-	"Intel\\(R\\) Pentium\\(R\\) CPU G2020T @ [0-9]\\.[0-9]{2}GHz", "Pentium",
-	"Intel\\(R\\) Pentium\\(R\\) 4 CPU [0-9]\\.[0-9]{2}GHz", "Pentium 4",
+	"Intel\\(R\\) Pentium\\(R\\) CPU G2020T @ [0-3]\\.[0-9]{2}GHz", "Pentium",
+	"Intel\\(R\\) Pentium\\(R\\) 4 CPU [0-3]\\.[0-9]{2}GHz", "Pentium 4",
 	"Intel\\(R\\) Pentium\\(R\\) M processor", "Pentium M",
 	"Intel\\(R\\) Pentium\\(R\\) M processor [0-9]{4}MHz", "Pentium M",
-	"Intel\\(R\\) Pentium\\(R\\) 4 Mobile CPU [0-9]\\.[0-9]{2}GHz","Pentium 4 Mobile",
-	"Intel\\(R\\) XEON\\(TM\\) CPU [0-9]\\.[0-9]{2}GHz", "Xeon",
-	"Intel\\(R\\) Xeon\\(TM\\) CPU [0-9]\\.[0-9]{2}GHz", "Xeon",
-	"Intel\\(R\\) Xeon\\(R\\) CPU           E5345  @ [0-9]\\.[0-9]{2}GHz","Xeon",
-	"Intel\\(R\\) Xeon\\(R\\) CPU           L5420  @ [0-9]\\.[0-9]{2}GHz","Xeon",
-	"Intel\\(R\\) Xeon\\(R\\) CPU E5-2650 v3 @ [0-9]\\.[0-9]{2}GHz", "Xeon",
+	"Intel\\(R\\) Pentium\\(R\\) 4 Mobile CPU [0-3]\\.[0-9]{2}GHz","Pentium 4 Mobile",
+	"Intel\\(R\\) XEON\\(TM\\) CPU [0-3]\\.[0-9]{2}GHz", "Xeon",
+	"Intel\\(R\\) Xeon\\(TM\\) CPU [0-3]\\.[0-9]{2}GHz", "Xeon",
+	"Intel\\(R\\) Xeon\\(R\\) CPU           E5345  @ [0-3]\\.[0-9]{2}GHz","Xeon",
+	"Intel\\(R\\) Xeon\\(R\\) CPU           L5420  @ [0-3]\\.[0-9]{2}GHz","Xeon",
+	"Intel\\(R\\) Xeon\\(R\\) CPU E5-2650 v3 @ [0-3]\\.[0-9]{2}GHz", "Xeon",
         "Celeron \\(Coppermine\\)", "Celeron (Coppermine)",
         "Celeron \\(Mendocino\\)", "Celeron (Mendocino)",
         "Celeron \\(Covington\\)", "Celeron (Covington)",
-	"Intel\\(R\\) Celeron\\(R\\) CPU [0-9]\\.[0-9]{2}GHz", "Celeron",
-	"Intel\\(R\\) Celeron\\(R\\) M processor         [0-9]\\.[0-9]{2}GHz", "Celeron M",
+	"Intel\\(R\\) Celeron\\(R\\) CPU [0-3]\\.[0-9]{2}GHz", "Celeron",
+	"Intel\\(R\\) Celeron\\(R\\) M processor         [0-3]\\.[0-9]{2}GHz", "Celeron M",
 	"Mobile Intel\\(R\\) Celeron\\(TM\\) CPU          [0-9]{3}MHz", "Mobile Celeron",
-	"Mobile Intel\\(R\\) Pentium\\(R\\) 4     CPU [0-9]\\.[0-9]{2}GHz", "Mobile Pentium 4",
-	"Intel\\(R\\) Core\\(TM\\) Solo CPU     U1400  @ [0-9]\\.[0-9]{2}GHz", "Core Solo",
-	"Intel\\(R\\) Core\\(TM\\)2 CPU          6600  @ [0-9]\\.[0-9]{2}GHz", "Core 2",
-	"Intel\\(R\\) Core\\(TM\\)2 Duo CPU     E[0-9]{3}0  @ [0-9]\\.[0-9]{2}GHz", "Core 2 Duo",
-	"Intel\\(R\\) Core\\(TM\\)2 Duo CPU     P8600  @ [0-9]\\.[0-9]{2}GHz", "Core 2 Duo",
-	"Intel\\(R\\) Core\\(TM\\)2 Quad CPU    Q6600  @ [0-9]\\.[0-9]{2}GHz", "Core 2 Quad",
-	"Intel\\(R\\) Core\\(TM\\)2 Quad CPU    Q9550  @ [0-9]\\.[0-9]{2}GHz", "Core 2 Quad",
-	"Intel\\(R\\) Core\\(TM\\) i5-6600 CPU @ [0-9]\\.[0-9]{2}GHz", "Core i5",
-	"Intel\\(R\\) Core\\(TM\\) i5-[0-9]{3}0U CPU @ [0-9]\\.[0-9]{2}GHz", "Core i5",
-	"Intel\\(R\\) Core\\(TM\\) i7-6600U CPU @ [0-9]\\.[0-9]{2}GHz", "Core i7",
-	"Intel\\(R\\) Core\\(TM\\) i7-6700T CPU @ [0-9]\\.[0-9]{2}GHz", "Core i7",
-	"Intel\\(R\\) Core\\(TM\\) i7-4600M CPU @ [0-9]\\.[0-9]{2}GHz", "Core i7",
-	"Genuine Intel\\(R\\) CPU            2140  @ [0-9]\\.[0-9]{2}GHz", "Pentium 4",
-	"Intel\\(R\\) Atom\\(TM\\) CPU N[0-9]{2}0   @ [0-9]\\.[0-9]{2}GHz", "Atom",
+	"Mobile Intel\\(R\\) Pentium\\(R\\) 4     CPU [0-3]\\.[0-9]{2}GHz", "Mobile Pentium 4",
+	"Intel\\(R\\) Core\\(TM\\) Solo CPU     U1400  @ [0-3]\\.[0-9]{2}GHz", "Core Solo",
+	"Intel\\(R\\) Core\\(TM\\)2 CPU          6600  @ [0-3]\\.[0-9]{2}GHz", "Core 2",
+	"Intel\\(R\\) Core\\(TM\\)2 Duo CPU     E[0-9]{3}0  @ [0-3]\\.[0-9]{2}GHz", "Core 2 Duo",
+	"Intel\\(R\\) Core\\(TM\\)2 Duo CPU     P8600  @ [0-3]\\.[0-9]{2}GHz", "Core 2 Duo",
+	"Intel\\(R\\) Core\\(TM\\)2 Quad CPU    Q6600  @ [0-3]\\.[0-9]{2}GHz", "Core 2 Quad",
+	"Intel\\(R\\) Core\\(TM\\)2 Quad CPU    Q9550  @ [0-3]\\.[0-9]{2}GHz", "Core 2 Quad",
+	"Intel\\(R\\) Core\\(TM\\) i5-6600 CPU @ [0-3]\\.[0-9]{2}GHz", "Core i5",
+	"Intel\\(R\\) Core\\(TM\\) i5-[0-9]{3}0U CPU @ [0-2]\\.[0-9]{2}GHz", "Core i5",
+	"Intel\\(R\\) Core\\(TM\\) i7-6600U CPU @ [0-3]\\.[0-9]{2}GHz", "Core i7",
+	"Intel\\(R\\) Core\\(TM\\) i7-6700T CPU @ [0-3]\\.[0-9]{2}GHz", "Core i7",
+	"Intel\\(R\\) Core\\(TM\\) i7-4600M CPU @ [0-3]\\.[0-9]{2}GHz", "Core i7",
+	"Genuine Intel\\(R\\) CPU            2140  @ [0-3]\\.[0-9]{2}GHz", "Pentium 4",
+	"Intel\\(R\\) Atom\\(TM\\) CPU N[0-9]{2}0   @ [0-3]\\.[0-9]{2}GHz", "Atom",
 #else
 	"K6 (166 - 266)", "K6",
         "AMD-K6tm w/ mul", "K6 (MMX)",
@@ -212,6 +212,7 @@ static char *models[] =
 	"Intel(R) Core(TM) i5-5300U CPU @ 2.30GHz", "Core i5",
 	"Intel(R) Core(TM) i5-6200U CPU @ 2.30GHz", "Core i5",
 	"Intel(R) Core(TM) i5-7200U CPU @ 2.50GHz", "Core i5",
+	"Intel(R) Core(TM) i5-8250U CPU @ 1.60GHz", "Core i5",
 	"Intel(R) Core(TM) i5-6600 CPU @ 3.30GHz", "Core i5",
 	"Intel(R) Core(TM) i7-4600M CPU @ 2.90GHz", "Core i7",
 	"Intel(R) Core(TM) i7-6600U CPU @ 2.60GHz", "Core i7",
@@ -270,7 +271,7 @@ void GetHardwareInfo(int fd, struct hw_stat *hw)
 				while ((models[i] != NULL)&&(!found))
 				{
 #ifdef use_regexp
-					if (regstrcmp(temp_string2, models[i], strlen(models[i])) == 0)
+					if (regstrcmp(temp_string2, models[i]) == 0)
 #else
 					if (strncmp(temp_string2, models[i], strlen(models[i])) == 0)
 #endif
