@@ -16,7 +16,7 @@
 	Copyright (C) 2003
 	Ola Lundqvist <opal@debian.org>
 
-	Copyright (C) 2005 
+	Copyright (C) 2005,2006,2014
 	Helge Kreutzmann <debian@helgefjell.de>
 
 
@@ -25,7 +25,7 @@
         1.0.0   AIB     199803??        Initial development
 	1.0.1	AIB	20000405	Rewritten
 	1.0.2	KRE	20051118        Include <string.h>
-	1.0.3	KRE	20060315	Fix memory reporting
+	see git history for later changes
 
         This is the S/390 port of linuxinfo
 */
